@@ -9,8 +9,8 @@
 #' @param F initial occasion vector 
 #' @param T number of occasions
 #' @param start matrix with values that are first occasion and for some CJS type models the state of first observation
-#' @aliases cjs_delta 
-#' @export
+#' @aliases cjs_delta mvmscjs_delta
+#' @export cjs_delta mvmscjs_delta
 #' @return 2-d array of initial state probability vectors for each id
 #' @author Jeff Laake <jeff.laake@@noaa.gov>
 #' @references Zucchini, W. and I.L. MacDonald. 2009. Hidden Markov Models for Time Series: An Introduction using R. Chapman and Hall, Boca Raton, FL. 275p. 
@@ -22,3 +22,12 @@ cjs_delta=function(pars,m,F,T,start)
 	delta[cbind(1:nrow(start),start[,1])]=1
 	delta 
 }
+mvmscjs_delta=function(pars,m,F,T,start) 
+{
+	if(is.list(m))m=m$ns*m$na+1
+	delta=matrix(0,nrow=nrow(start),ncol=m,byrow=TRUE)
+	delta[,1:(m-1)]=pars$pi
+	delta=delta/rowSums(delta)
+	delta 
+}
+
