@@ -12,7 +12,7 @@
 #' @return array of id and occasion-specific transition matrices - Gamma in Zucchini and MacDonald (2009)
 #' @author Jeff Laake <jeff.laake@@noaa.gov>
 #' @references Zucchini, W. and I.L. MacDonald. 2009. Hidden Markov Models for Time Series: An Introduction using R. Chapman and Hall, Boca Raton, FL. 275p. 
- cjs_gamma=function(pars,m,F,T) 
+cjs_gamma=function(pars,m,F,T) 
  {
 	phimat=array(0,c(nrow(pars$Phi),T-1,m,m))
  	# create 4-d array with a matrix for each id and occasion
@@ -45,7 +45,8 @@ cjs2tl_gamma=function(pars,m,F,T)
 ms_gamma=function(pars,m,F,T) 
 {
 	 # create 4-d array with a matrix for each id and occasion
-	 # from pars$Phi which is a matrix of id by occasion survival probabilities 	
+	 # from pars$S  which is a matrix of id by occasion survival probabilities 
+	 # and pars$Psi which is state transitions
 	if(is.list(m))m=m$ns*m$na+1
 	value=.Fortran("msgam",as.double(pars$S),as.double(pars$Psi),as.integer(nrow(pars$S)),as.integer(m),
 			 as.integer(F),as.integer(T),tmat=double(nrow(pars$S)*(T-1)*m^2),PACKAGE="marked")
@@ -63,6 +64,16 @@ ms_gamma=function(pars,m,F,T)
 	 dim(value$tmat)=c(nrow(pars$S),T-1,ns,ns)
 	 value$tmat
  }
+ mvms_gamma=function(pars,m,F,T) 
+ {
+	 # create 4-d array with a matrix for each id and occasion
+#	 # from pars$Phi which is a matrix of id by occasion survival probabilities 
+	 # and pars$Psi which is state transitions
+	 value=.Fortran("msgam",as.double(pars$Phi),as.double(pars$Psi),as.integer(nrow(pars$Phi)),as.integer(m),
+			 as.integer(F),as.integer(T),tmat=double(nrow(pars$Phi)*(T-1)*m^2),PACKAGE="marked")
+	 dim(value$tmat)=c(nrow(pars$Phi),T-1,m,m)
+	 value$tmat
+ }
 # R versions of the FORTRAN code
 #  cjs_gamma=function(pars,m,F,T) 
 #  {
@@ -108,6 +119,41 @@ ms_gamma=function(pars,m,F,T)
 #	# The 4-d arrays are multiplied and returned
 #	phimat*psimat
 #}
+# Following wasn't really needed since it only made change from S to Phi
+# and made sure it only used F[i]<T.The latter was put into FORTRAN code for msgamma 
+#mvms_gamma=function(pars,m,F,T) 
+#{
+#	# create an 4-d array with a matrix for each id and occasion for S from pars$S 
+#	# which is a matrix of id by occasion x state survival probabilities
+#	if(is.list(m))m=m$ns*m$na+1
+#	phimat=array(0,c(nrow(pars$Phi),T-1,m,m))
+#	for (i in 1:nrow(phimat))
+#	{
+#		if(F[i]<=(T-1))
+#		for(j in F[i]:(T-1))
+#		{
+#			s=pars$Phi[i,((j-1)*(m-1)+1):(j*(m-1))]
+#			smat=matrix(s,ncol=length(s),nrow=length(s))
+#			phimat[i,j,,]=rbind(cbind(smat,1-s),c(rep(0,length(s)),1))
+#		}
+#	}
+#	# create a 4-d array from pars$Psi which is a matrix of id by occasion x state^2 
+#	# non-normalized Psi probabilities which are normalized to sum to 1. 
+#	psimat=array(0,c(nrow(pars$Psi),T-1,m,m))
+#	for (i in 1:nrow(psimat))
+#	{
+#		if(F[i]<=(T-1))
+#		for(j in F[i]:(T-1))
+#		{
+#			psi=pars$Psi[i,((j-1)*(m-1)^2+1):(j*(m-1)^2)]
+#           psix=matrix(psi,ncol=sqrt(length(psi)),byrow=TRUE)
+#			psix=psix/rowSums(psix)
+#			psimat[i,j,,]=rbind(cbind(psix,rep(1,nrow(psix))),rep(1,nrow(psix)+1))
+#		}
+#	}
+#	# The 4-d arrays are multiplied and returned
+#	phimat*psimat
+#}
 #ms2_gamma=function(pars,m,F,T) 
 #{
 #	# create an 4-d array with a matrix for each id and occasion for S from pars$S 
