@@ -161,11 +161,6 @@ cjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL,m
 ########################################################################
 #      CJS with ADMB
 ########################################################################
-	   if(R.Version()$os=="mingw32")
-		   ext=".exe"
-       else
-		   ext=""
-	   sdir=system.file(package="marked")
 	   # set tpl filename
 	   if(!crossed)
 	   {
@@ -177,45 +172,10 @@ cjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL,m
 		   else
 			   tpl="cjs"
 	   }
-	   # cleanup any leftover files
-	   clean_admb(tpl)
-	   # if argument clean is TRUE, delete exe and TPL files as well
-	   if(clean)
-	   {
-		  if(file.exists(paste(tpl,".tpl",sep=""))) unlink(paste(tpl,".tpl",sep=""))
-		  if(file.exists(paste(tpl,ext,sep=""))) unlink(paste(tpl,ext,sep=""))
-	  }
-	   # if tpl is not available, copy from the package directory
-	   if(!file.exists(paste(tpl,".tpl",sep="")))
-	   {
-		   file.copy(file.path(sdir,paste(tpl,".tpl",sep="")),file.path(getwd(),paste(tpl,".tpl",sep="")),overwrite=TRUE)
-		   file.copy( file.path(sdir,list.files(sdir,"*.cpp")),file.path(getwd()),overwrite=TRUE)
-	   } 
-	   # if exe available in the package or workspace directory use it
-       have.exe=TRUE
-	   if(!file.exists(file.path(getwd(),paste(tpl,ext,sep=""))))
-	   {
-		   if(file.exists(file.path(sdir,paste(tpl,ext,sep=""))) &!compile)
-		   {
-			   file.copy(file.path(sdir,paste(tpl,ext,sep="")),file.path(getwd(),paste(tpl,ext,sep="")),overwrite=TRUE)
-		   }else
- 	       # if there is no exe in either place then check to make sure ADMB is installed and linked
-		   {
-			  have.exe=FALSE
-		   }
-	   }
-	   if(!have.exe | compile)
-	   {
-		   # no exe or compile set TRUE; see if admb can be found; this is not a complete test but should catch the novice user who has
-	       # not setup admb at all
-	       if(R.Version()$os=="mingw32" & Sys.which(paste("tpl2cpp",ext,sep=""))=="")
-			  stop("admb not found; setup links to admb and c++ compiler with environment variables or put in path")
-		   else
-		   {
-			  compile_admb(tpl,re=TRUE,safe=TRUE,verbose=T)
-		   }
-	   }
-	   # create admbcjs.dat file to create its contents 
+	   # setup admb exe and cleanup old files and previous tpl; checks for exe 
+	   # in package directory and if found uses it otherwise compiles tpl file
+	   setup_admb(tpl,compile=compile,clean=clean,re=TRUE)
+	   # open data file to create its contents 
 	   con=file(paste(tpl,".dat",sep=""),open="wt")
 	   # Number of observations
 	   n=length(model_data$imat$freq)
@@ -354,7 +314,7 @@ cjs=function(x,ddl,dml,model_data=NULL,parameters,accumulate=TRUE,initial=NULL,m
 	   options=list(extra.args=extra.args)
 	   res$cor=NULL
 	   res$maxgrad=NULL
-	   results=c(beta=beta,neg2lnl=-2*res$loglik,AIC=-2*res$loglik+2*res$npar,convergence=convergence)
+	   results=c(beta=beta,neg2lnl=-2*res$loglik,AIC=-2*res$loglik+2*sum(sapply(cjs.beta,length)),convergence=convergence)
 	   results$optim.details=optim.details
 	   results$options=options
 	   results$random.effects=res$random.effects
