@@ -201,7 +201,9 @@ full.design.data=vector("list",length=length(parameters))
 	  {
 		  full.design.data[[i]]$fix=NA
 		  full.design.data[[i]]$fix[as.character(full.design.data[[i]]$time)==as.character(full.design.data[[i]]$cohort)]=1	  
+		  full.design.data[[i]]$fix[as.numeric(as.character(full.design.data[[i]]$time))<as.numeric(as.character(full.design.data[[i]]$cohort))]=0  
 	  }	
+	  if(parameters[[i]]$firstonly) full.design.data[[i]]= full.design.data[[i]][as.character(full.design.data[[i]]$cohort)==as.character(full.design.data[[i]]$time),]
 	  full.design.data[[i]]=droplevels(full.design.data[[i]])
 	  if(names(parameters)[i]=="tau"&!is.null(full.design.data[[i]]$tag1))
 	  {
@@ -213,8 +215,67 @@ full.design.data=vector("list",length=length(parameters))
    names(full.design.data)=names(parameters)
    full.design.data[["design.parameters"]]=parameters
    full.design.data$ehmat=data$ehmat
+   if(data$model=="MVMSCJS")
+	   full.design.data=initiate_pi(data,full.design.data)
    return(full.design.data)
 }
-
-        
+#' Setup fixed values for pi in design data
+#' 
+#' Creates field fix in pi design data and either sets to NA to be estimated
+#' or 1 if intercept or 0 if not possible. It uses observed data at initial
+#' entry to decide the appropriate fix values.
+#' 
+#' It is possible that the state will be known for some individuals
+#' and unknown for others.  The function initiate_pi modifies the design data for pi by adding
+#' the field fix which can be used to fix the value of pi for an individual with known state
+#' at release. It also sets up the mlogit structure for pi by setting one of the fixed values to 1
+#' such that the value for pi is computed by subtraction.  By default it chooses the first factor level
+#' of each of the state variables that is unknown.  If some of the state variables are known but others are not, 
+#' it sets fix to 0 for the values of the known state variables that don't match the known value.  
+#' 
+#' For example, with a bivariate case with first state A,B or C and second variable 1 or 2.  Only the second
+#' variable can be unknown. There are 6 possible combinations of the state variables: A1,A2,B2,B2,C1,C2.
+#' Assume a capture history is 0,Au,0,B1,B2.  There will be 6 records in the design data for this record
+#' with strata A1,A2,B2,B2,C1,C2. The occ (occasion field) will be 2 because pi is only for the first occasion.
+#' After running initiate_pi, the fix values will be 1,NA,0,0,0,0.  A1 will be the intercept and computed 
+#' by subtraction (fix=1), the value for A2 will be estimated (NA) and all of the others
+#' are not possible (0) because it is known to be in A.
+#' 
+#' If both can be uncertain, and the capture history was  0,uu,0,B1,B2, then the fix values will be
+#' 1,NA,NA,NA,NA,NA. With a mix of partially known and completely unknown the formulation for the mlogit could
+#' get complicated making it difficult to specify an understandable formula because the restrictions on the
+#' mlogit will change, so think hard and long about what you are doing.  It may be necessary to construct "multiple" formula
+#' in the sense that you use indicator variables (0/1) as interactions. 
+#' 
+#' @param data Processed data list; resulting value from process.data
+#' @param ddl design data list created by make.design.data
+#' @return ddl with fix field added to pi dataframe
+#' @author Jeff Laake
+#' @export
+initiate_pi=function(data,ddl)
+{
+set_pifix=function(id)
+{
+	strata=ddl$pi$stratum[ddl$pi$id==id]
+	first_value=strsplit(data$data$ch[data$data$id==id],",")[[1]][unique(ddl$pi$occ[ddl$pi$id==id])]
+	unknown=grep("u",first_value)
+	fix=rep(0,nrow(ddl$pi[data$data$id==id,]))
+	if(length(unknown)==0)
+		fix[strata==first_value]=1
+	else
+	{
+		match_value= gsub("u","\\\\S",first_value)
+		match_value= gsub("\\+","\\\\+",match_value)
+		match_value= gsub("\\-","\\\\-",match_value)
+		fix[!regexpr(match_value,strata)==-1]=NA
+		splitch=strsplit(first_value,"")[[1]]
+		whichu=grep("u",splitch,fixed=TRUE)
+		splitch[whichu]=strsplit(levels(ddl$pi$stratum)[1],"")[[1]][whichu]
+		fix[strata==paste(splitch,collapse="")]=1
+	}
+	return(fix)
+}
+ddl$pi$fix=as.vector(sapply(data$data$id,set_pifix))
+return(ddl)
+}
          
