@@ -242,9 +242,8 @@ probitCJS = function(ddl,dml,parameters,design.parameters,burnin, iter, initial=
     
     ### BETA.Z UPDATE ###
     idx.z.tilde = make.ztilde.idx(id, zvec)
-    Q.b.z = tau.b.z*crossprod(Xz[idx.z.tilde,])
-    V.beta.z.inv = crossprod(Xz[idx.z.tilde,]) + Q.b.z
-    m.beta.z = solve(V.beta.z.inv, crossprod(Xz[idx.z.tilde,],z.tilde[idx.z.tilde]-eta.phi[idx.z.tilde]) + crossprod(Q.b.z,mu.b.z))
+    V.beta.z.inv = crossprod(Xz[idx.z.tilde,]) + tau.b.z
+    m.beta.z = solve(V.beta.z.inv, crossprod(Xz[idx.z.tilde,],z.tilde[idx.z.tilde]-eta.phi[idx.z.tilde]) + tau.b.z*mu.b.z)
     beta.z = m.beta.z + solve(chol(V.beta.z.inv), rnorm(ncol(Xz),0,1))
     if(m>burnin)beta.z.stor[m-burnin,] = beta.z
     
@@ -254,9 +253,8 @@ probitCJS = function(ddl,dml,parameters,design.parameters,burnin, iter, initial=
     y.tilde = truncnorm::rtruncnorm(n, a=a, b=b, mean=as.vector(Xy%*%beta.y+eta.p), sd=1)
     
     ### BETA.Y UPDATE ###
-    Q.b.y = tau.b.y*crossprod(Xy[zvec==1,])
-    V.beta.y.inv = crossprod(Xy[zvec==1,]) + Q.b.y
-    m.beta.y = solve(V.beta.y.inv, crossprod(Xy[zvec==1,],y.tilde[zvec==1]-eta.p[zvec==1])+crossprod(Q.b.y,mu.b.y))
+    V.beta.y.inv = crossprod(Xy[zvec==1,]) + tau.b.y
+    m.beta.y = solve(V.beta.y.inv, crossprod(Xy[zvec==1,],y.tilde[zvec==1]-eta.p[zvec==1])+tau.b.y*mu.b.y)
     beta.y = m.beta.y + solve(chol(V.beta.y.inv), rnorm(ncol(Xy),0,1))
     if(m>burnin) beta.y.stor[m-burnin,] = beta.y
     
